@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 using System;
@@ -413,7 +411,7 @@ namespace gbrainy.Clients.Classical
 
 		void OnMenuHelp (object sender, EventArgs args)
 		{
-			Unix.ShowUri (null, "ghelp:gbrainy",
+			Unix.ShowUri (null, "help:gbrainy",
 				Gdk.EventHelper.GetTime (new Gdk.Event(IntPtr.Zero)));
 		}
 
@@ -649,9 +647,9 @@ namespace gbrainy.Clients.Classical
 		void OnActivateToolbar (object sender, System.EventArgs args)
 		{
 			int width, height;
-			Requisition requisition;
+			Requisition minimum_size, natural_size;
 
-			requisition = toolbar.SizeRequest ();
+			toolbar.GetPreferredSize(out minimum_size, out natural_size);
 			app_window.GetSize (out width, out height);
 			toolbar.Visible = !toolbar.Visible;
 
@@ -665,7 +663,7 @@ namespace gbrainy.Clients.Classical
 				Preferences.Set <bool> (Preferences.ToolbarShowKey, toolbar.Visible);
 				Preferences.Save ();
 			}
-			app_window.Resize (width, height - requisition.Height);
+			app_window.Resize (width, height - natural_size.Height);
 		}
 
 		void OnVerticalToolbar (object sender, System.EventArgs args)
@@ -721,7 +719,7 @@ namespace gbrainy.Clients.Classical
 
 		void OnExtending (object sender, EventArgs args)
 		{
-			Process.Start ("https://wiki.gnome.org/Apps/gbrainy/Extending");
+			Process.Start ("https://wiki.gnome.org/gbrainy/Extending");
 		}
 
 		static void InitCoreLibraries ()
