@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 using System;
@@ -42,6 +40,8 @@ namespace gbrainy.Core.Main
 		public const string ThemeKey = "Theme";
 		public const string EnglishKey = "English";
 		public const string EnglishVersionKey = "EnglishVersion";
+		public const string LoadPlugginsKey = "LoadExtensions";
+		public const string SoundsKey = "Sounds";
 
 		static Preferences ()
 		{
@@ -139,6 +139,8 @@ namespace gbrainy.Core.Main
 			defaults.Add (ThemeKey, "notebook");
 			defaults.Add (EnglishVersionKey, string.Empty);
 			defaults.Add (EnglishKey, false.ToString ());
+			defaults.Add (LoadPlugginsKey, false.ToString ());
+			defaults.Add (SoundsKey, true.ToString ());
 		}
 
 		public static void Load ()
