@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -44,8 +42,9 @@ namespace gbrainy.Core.Views
 		readonly Cairo.Color desc_color = new Color (0.3, 0.3, 0.3);
 		PlayerHistory history;
 
-		public PlayerHistoryView (PlayerHistory history)
+		public PlayerHistoryView (ITranslations translations, PlayerHistory history)
 		{
+			Translations = translations;
 			this.history = history;
 			ShowLogic = ShowMemory = ShowCalculation = ShowVerbal = true;
 		}
@@ -55,6 +54,7 @@ namespace gbrainy.Core.Views
 		public bool ShowMemory { get; set; }
 		public bool ShowCalculation { get; set; }
 		public bool ShowVerbal { get; set; }
+		private ITranslations Translations { get; set; }
 
 		void DrawAxisDescription (CairoContextEx cr, double x, double y, string description)
 		{
@@ -80,7 +80,7 @@ namespace gbrainy.Core.Views
 			cr.Stroke ();
 			cr.Color = text_color;
 			cr.MoveTo (x + line_size + offset_x, y - 0.01);
-			cr.ShowPangoText (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Total"));
+			cr.ShowPangoText (Translations.GetString ("Total"));
 			cr.Stroke ();
 
 			cr.Color = logic_color;
@@ -89,7 +89,7 @@ namespace gbrainy.Core.Views
 			cr.Stroke ();
 			cr.Color = text_color;
 			cr.MoveTo (x + line_size + offset_x, y - 0.01 + second_row);
-			cr.ShowPangoText (GameTypesDescription.GetLocalized (GameTypes.LogicPuzzle));
+			cr.ShowPangoText (GameTypesDescription.GetLocalized (Translations, GameTypes.LogicPuzzle));
 			cr.Stroke ();
 
 			x += space_hor;
@@ -99,7 +99,7 @@ namespace gbrainy.Core.Views
 			cr.Stroke ();
 			cr.Color = text_color;
 			cr.MoveTo (x + line_size + offset_x, y - 0.01);
-			cr.ShowPangoText (GameTypesDescription.GetLocalized (GameTypes.Memory));
+			cr.ShowPangoText (GameTypesDescription.GetLocalized (Translations, GameTypes.Memory));
 			cr.Stroke ();
 
 			cr.Color = math_color;
@@ -108,7 +108,7 @@ namespace gbrainy.Core.Views
 			cr.Stroke ();
 			cr.Color = text_color;
 			cr.MoveTo (x + line_size + offset_x, y - 0.01 + second_row);
-			cr.ShowPangoText (GameTypesDescription.GetLocalized (GameTypes.Calculation));
+			cr.ShowPangoText (GameTypesDescription.GetLocalized (Translations, GameTypes.Calculation));
 			cr.Stroke ();
 
 			x += space_hor;
@@ -118,7 +118,7 @@ namespace gbrainy.Core.Views
 			cr.Stroke ();
 			cr.Color = text_color;
 			cr.MoveTo (x + line_size + offset_x, y - 0.01);
-			cr.ShowPangoText (GameTypesDescription.GetLocalized (GameTypes.VerbalAnalogy));
+			cr.ShowPangoText (GameTypesDescription.GetLocalized (Translations, GameTypes.VerbalAnalogy));
 			cr.Stroke ();
 
 			cr.LineWidth = old_width;
@@ -271,8 +271,8 @@ namespace gbrainy.Core.Views
 			DrawLegend (cr, x + grid_offsetx, y + area_h + 0.06);
 			DrawGrid (cr, grid_x, grid_y);
 
-			DrawAxisDescription (cr, x + area_w + 0.01, 0.78, ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Time"));
-			DrawAxisDescription (cr, 0, 0.03, ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Score"));
+			DrawAxisDescription (cr, x + area_w + 0.01, 0.78, Translations.GetString ("Time"));
+			DrawAxisDescription (cr, 0, 0.03, Translations.GetString ("Score"));
 		}
 	}
 }
