@@ -12,15 +12,13 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 using System;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Services;
+
 
 namespace gbrainy.Games.Logic
 {
@@ -46,21 +44,21 @@ namespace gbrainy.Games.Logic
 		private const double figure_width = 0.1, figure_height = 0.1, space_width = 0.05, space_height = 0;
 
 		public override string Name {
-			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Balance");}
+			get {return Translations.GetString ("Balance");}
 		}
 
 		public override string Question {
-			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Using triangles only, how many triangles are needed in the right part of the last figure to keep it balanced?");}
+			get {return Translations.GetString ("Using triangles only, how many triangles are needed in the right part of the last figure to keep it balanced?");}
 		}
 
 		public override string Rationale {
 			get {
-				return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Every circle is equivalent to two triangles and every square to three triangles.");
+				return Translations.GetString ("Every circle is equivalent to two triangles and every square to three triangles.");
 			}
 		}
 
 		public override string Tip {
-			get { return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Every circle is equivalent two triangles.");}
+			get { return Translations.GetString ("Every circle is equivalent two triangles.");}
 		}
 
 		protected override void Initialize ()
@@ -76,16 +74,11 @@ namespace gbrainy.Games.Logic
 
 		public void DrawBalance (CairoContextEx gr, double x, double y, int index, bool full)
 		{
+
 			const double width = 0.5;
-			double fig_x = x + 0.1, fig_y = y - 0.11;
+			double fig_x = x + 0.1, fig_y = y - 0.08;
 			int total = (full == true) ? (elements * 2) : elements;
 
-			gr.Rectangle (x + 0.05, y - 0.12, 0.38, 0.08);
-			gr.Stroke ();
-
-			gr.Rectangle (x + 0.5, y - 0.12, 0.38, 0.08);
-			gr.Stroke ();
-
 			for (int i = 0; i < total; i++) {
 				switch (balances[i + index]) {
 				case 1:
@@ -107,19 +100,7 @@ namespace gbrainy.Games.Logic
 					fig_x += 0.07;
 			}
 
-			x += 0.2;
-			y += 0.01;
-			gr.MoveTo (x, y);
-			gr.LineTo (x + width, y);
-			gr.LineTo (x + width, y - 0.05);
-			gr.Stroke ();
-
-			gr.MoveTo (x , y);
-			gr.LineTo (x , y - 0.05);
-			gr.Stroke ();
-
-			gr.DrawEquilateralTriangle (x + (width / 2) - 0.04, y, 0.08);
-			gr.Stroke ();
+			gr.DrawImageFromAssembly ("balance.svg", x + 0.02, y - 0.08, 0.9, 0.25);
 		}
 
 		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
@@ -137,7 +118,7 @@ namespace gbrainy.Games.Logic
 			DrawBalance (gr, x, y, (group * elements * 6) + 2 * elements * 2, false);
 
 			gr.SetPangoFontSize (0.05);
-			gr.MoveTo (0.74, 0.68);
+			gr.MoveTo (0.74, 0.71);
 			gr.ShowPangoText ("?");
 			gr.Stroke ();
 		}
